FillColor

Struct FillColor 

pub struct FillColor(/* private fields */);
Represents the fill color of a rectangle

Can be a single color or a simple gradient with different colors for each corner

Implementations

Source

impl FillColor

pub const TRANSPARENT: Self

Transparent background (alpha = 0)

pub const fn new(corners: Corners<Vec4>) -> Self

pub const fn transparent() -> Self

Transparent background (alpha = 0)

pub fn is_transparent(&self) -> bool

Check if the fill color is completely transparent

(i.e. all corners have an alpha value of 0.0)

pub fn is_opaque(&self) -> bool

Check if the fill color is completely opaque

(i.e. all corners have an alpha value of 1.0)

pub const fn rgba(r: f32, g: f32, b: f32, a: f32) -> Self

Construct a solid color fill from values representing the red, green, blue and alpha channels

pub const fn rgb(r: f32, g: f32, b: f32) -> Self

Construct a solid color fill from three values representing the red, green and blue channels

pub const fn from_corners(corners: Corners<Vec4>) -> Self

Construct a solid color fill from colors for each corner

pub const fn corners(&self) -> Corners<Vec4>

Get a list of the colors for each corner

pub fn interpolate(&self, uv: Vec2) -> Vec4

Interpolate color on position, assuming a linear gradient