Rect

Struct Rect 

pub struct Rect {
    pub position: Vec2,
    pub size: Vec2,
}
Represents a rectangle/AABB with specified position and size

Fields

position: Vec2

Position of the top-left corner of the rect.

size: Vec2

Size of the rect, should not be negative.

Implementations

Source

impl Rect

pub const fn new(position: Vec2, size: Vec2) -> Self

pub const fn from_position(position: Vec2) -> Self

pub const fn from_size(size: Vec2) -> Self

pub fn contains_point(&self, point: Vec2) -> bool

Check if the rect contains a point.

pub fn intersects_rect(&self, other: Rect) -> bool

Check if the rect intersects with another rect.

pub fn width(&self) -> f32

Get width of the rectangle.

To get both width and height, use the size property instead.

pub fn height(&self) -> f32

Get height of the rectangle.

To get both width and height, use the size property instead.

pub fn x(&self) -> f32

Get position of the top-left corner of the rectangle on the x-axis.

To get both x and y, use the position property instead.

pub fn y(&self) -> f32

Get position of the top-left corner of the rectangle on the y-axis.

To get both x and y, use the position property instead.

pub fn corners(&self) -> Corners<Vec2>

Get positions of all 4 corners of the rectangle.